@@ -6,6 +6,7 @@ module.exports = {
   createInboxStream: 'source',
   createBookmarkStream: 'source',
   createNotificationsStream: 'source',
+  createChannelStream: 'source',
 
   markRead: 'async',
   markUnread: 'async',
@@ -17,6 +18,11 @@ module.exports = {
   toggleBookmark: 'async',
   isBookmarked: 'async',
 
+  getChannels: 'async',
+  pinChannel: 'async',
+  unpinChannel: 'async',
+  toggleChannelPinned: 'async',
+
   addFileToBlobs: 'async',
   saveBlobToFile: 'async',
 
