@@ -5,8 +5,13 @@ var pullipc    = require('pull-ipc')
 
 var clientApi = {
   navigate: 'async',
+  navigateHistory: 'async',
+  navigateToggle: 'async',
   contextualToggleDevTools: 'async',
   triggerFind: 'async',
+  findNext: 'async',
+  findPrevious: 'async',
+  focusSearch: 'async',
   zoomIn: 'async',
   zoomOut: 'async',
   zoomReset: 'async'
