@@ -12,11 +12,16 @@ export default class ComposerCard extends React.Component {
   onClick() {
     this.setState({ isOpen: true }, () => {
       // focus the textarea
-      this.refs.container.querySelector('input[type=text], textarea').focus()
+      if (this.props.recps) // if recps are provided, focus straight onto the textarea
+        this.refs.container.querySelector('textarea').focus()
+      else
+        this.refs.container.querySelector('input[type=text], textarea').focus()
     })
   }
-  onSend() {
+  onSend(msg) {
     this.setState({ isOpen: false })
+    if (this.props.onSend)
+      this.props.onSend(msg)
   }
   render() {
     return <div ref="container" className={'composer-card '+(this.state.isOpen?'open':'')}>
