@@ -12,6 +12,7 @@ import ReactInfinite from 'react-infinite'
 import classNames from 'classnames'
 import ComposerCard from './composer/card'
 import SimpleInfinite from './simple-infinite'
+import ResponsiveElement from './responsive-element'
 import Summary from './msg-view/summary'
 import { VerticalFilledContainer, verticalFilled } from './index'
 import { isaReplyTo } from '../lib/msg-relation'
@@ -245,7 +246,7 @@ export default class MsgList extends React.Component {
 
   processMsg(msg, cb) {
     // fetch thread data if not already present (using `related` as an indicator of that)
-    if (this.props.threads && !('related' in msg)) {
+    if (this.props.threads && msg.value && !('related' in msg)) {
       threadlib.getPostSummary(app.ssb, msg.key, cb)
     } else
       cb(null, msg) // noop
@@ -340,6 +341,7 @@ export default class MsgList extends React.Component {
   render() {
     const Hero = this.props.Hero
     const LeftNav = this.props.LeftNav
+    const RightNav = this.props.RightNav
     const Toolbar = this.props.Toolbar
     const Infinite = this.props.listItemHeight ? ReactInfinite : SimpleInfinite // use SimpleInfinite if we dont know the height of each elem
     const ListItem = this.props.ListItem || Summary
@@ -375,31 +377,38 @@ export default class MsgList extends React.Component {
                   { (this.props.emptyMsg || 'No messages.') }
                 </div>
                 :
-                <ReactCSSTransitionGroup component="div" transitionName="fade" transitionAppear={true} transitionAppearTimeout={500} transitionEnterTimeout={500} transitionLeaveTimeout={1}>
-                  { this.state.msgs.map((m, i) => {
-                    // render item
-                    const item = <ListItem
-                      key={m.key}
-                      msg={m}
-                      {...this.handlers}
-                      {...this.props.listItemProps}
-                      selected={selectedKey === m.key}
-                      forceRaw={this.props.forceRaw} />
+                <ResponsiveElement widthStep={250}>
+                  <ReactCSSTransitionGroup component="div" transitionName="fade" transitionAppear={true} transitionAppearTimeout={500} transitionEnterTimeout={500} transitionLeaveTimeout={1}>
+                    { this.state.msgs.map((m, i) => {
+                      // missing value?
+                      if (!m.value)
+                        return <span key={m.key} /> // dont render
 
-                    // render a date divider if this post is from a different day than the last
-                    const oldLastDate = lastDate
-                    const lastPost = threadlib.getLastThreadPost(m)
-                    lastDate = moment(lastPost.value.timestamp)
-                    if (this.props.dateDividers && !lastDate.isSame(oldLastDate, 'day')) {
-                      let label = (lastDate.isSame(endOfToday, 'day')) ? 'today' : lastDate.endOf('day').from(endOfToday)
-                      return <div key={m.key}><hr className="labeled" data-label={label} />{item}</div>
-                    }
-                    return item
-                  }) }
-                </ReactCSSTransitionGroup>
+                      // render item
+                      const item = <ListItem
+                        key={m.key}
+                        msg={m}
+                        {...this.handlers}
+                        {...this.props.listItemProps}
+                        selected={selectedKey === m.key}
+                        forceRaw={this.props.forceRaw} />
+
+                      // render a date divider if this post is from a different day than the last
+                      const oldLastDate = lastDate
+                      const lastPost = threadlib.getLastThreadPost(m)
+                      lastDate = moment(lastPost.value.timestamp)
+                      if (this.props.dateDividers && !lastDate.isSame(oldLastDate, 'day')) {
+                        let label = (lastDate.isSame(endOfToday, 'day')) ? 'today' : lastDate.endOf('day').from(endOfToday)
+                        return <div key={m.key}><hr className="labeled" data-label={label} />{item}</div>
+                      }
+                      return item
+                    }) }
+                  </ReactCSSTransitionGroup>
+                </ResponsiveElement>
               }
               {append}
             </div>
+            { RightNav ? <RightNav {...this.props.rightNavProps} /> : '' }
           </div>
         </Infinite>
       </div>
