@@ -10,6 +10,7 @@ import ProfileSetup from './com/forms/profile-setup'
 import FollowNearby from './com/forms/follow-nearby'
 import PubInvite from './com/forms/pub-invite'
 import Issues from './com/issues'
+import FindBar from './com/findbar'
 
 const SETUP_LABELS = [<i className="fa fa-user"/>, <i className="fa fa-wifi"/>, <i className="fa fa-cloud"/>]
 const SETUP_FORMS = [ProfileSetup, FollowNearby, PubInvite]
@@ -28,7 +29,12 @@ export default class Layout extends React.Component {
     app.on('update:all', refresh)
     app.on('update:indexCounts', refresh)
     app.on('update:isWifiMode', refresh)
+    app.on('focus:search', this.focusSearch.bind(this))
+    app.on('focus:find', this.focusFind.bind(this))
+    app.on('toggle:rightnav', this.toggleRightNav.bind(this))
     app.on('modal:setup', isOpen => this.setState({ setupIsOpen: isOpen }))
+    app.on('find:next', this.doFind.bind(this, true))
+    app.on('find:previous', this.doFind.bind(this, false))
   }
   componentWillReceiveProps() {
     // update state on view changes
@@ -56,6 +62,18 @@ export default class Layout extends React.Component {
       this.setState({ rightNav: id })
   }
 
+  focusSearch() {
+     this.refs.search.focus()
+  }
+
+  focusFind() {
+    this.refs.find.focus()
+  }
+
+  doFind(forward) {
+    this.refs.find.search(forward)
+  }
+
   onClickBack() {
     window.history.back()
   }
@@ -117,13 +135,14 @@ export default class Layout extends React.Component {
           <NavToggle to="notifications" icon="bell" count={this.state.indexCounts.notificationsUnread} />
         </div>
         <div>
-          <div className="search"><i className="fa fa-search" /><input onKeyDown={this.onSearchKeyDown.bind(this)} /></div>
+          <div className="search"><i className="fa fa-search" /><input ref="search" onKeyDown={this.onSearchKeyDown.bind(this)} /></div>
         </div>
       </div>
       <div className="layout-columns">
         <div id="mainview">{this.props.children}</div>
         { (RightNavView) ? <div id="rightnav"><RightNavView location={this.props.location} {...this.state.rightNavProps} /></div> : '' }
       </div>
+      <FindBar ref="find" for="mainview" />
     </div>
   }
 }
\ No newline at end of file
